## ESA CCI Toolbox Notebooks Setup

To run the Notebooks in this folder, you will need a Python environment 
with the [`ESA CCI Toolbox`](https://github.com/esa-cci/esa-climate-toolbox) 
installed.
For creating such an environment follow the instructions given in the 
[README](https://github.com/esa-cci/esa-climate-toolbox/blob/main/README.md).

Before using Jupyter Lab for the first time install the `jupyterlab` and 
`jupyterlab-geojson` package. 

```bash
(ect) conda install -c conda-forge jupyterlab jupyterlab-geojson
```

### Running Jupyter Lab

Start Jupyter Lab:

```bash
(ect) $ jupyter-lab
```
